@@ -2,7 +2,7 @@
 #'
 #' This function provides a tibble containing total population estimates for Brazilian municipalities.
 #'
-#' @param source character. `datasus` for Brazilian Health Ministry estimates (2000 to 2021), `ufrn` for UFRN-DEM-LEPP estimates (2010 to 2030), or `ibge` for IBGE estimates (2000 to 2022).
+#' @param source character. `datasus` for Brazilian Health Ministry old estimates (2000 to 2021), `datasus2024` for Brazilian Health Ministry new estimates (2000 to 2024), `ufrn` for UFRN-DEM-LEPP estimates (2010 to 2030), or `ibge` for IBGE estimates (2000 to 2022).
 #'
 #' @returns A tibble.
 #' @seealso [datasus_mun_male_pop], [datasus_mun_female_pop], [ufrn_mun_male_pop], [ufrn_mun_female_pop], [ibge_pop].
@@ -12,7 +12,7 @@
 
 mun_pop_totals <- function(source = "datasus"){
   # Assertions
-  checkmate::assert_choice(x = source, choices = c("datasus", "ufrn", "ibge"))
+  checkmate::assert_choice(x = source, choices = c("datasus", "ufrn", "ibge", "datasus2024"))
 
   # Estimates source
   if(source == "datasus"){
@@ -21,9 +21,12 @@ mun_pop_totals <- function(source = "datasus"){
   } else if(source == "ufrn"){
     mun_male_pop <- ufrn_mun_male_pop()
     mun_female_pop <- ufrn_mun_female_pop()
+  } else if(source == "datasus2024"){
+    mun_male_pop <- datasus2024_mun_male_pop()
+    mun_female_pop <- datasus2024_mun_female_pop()
   }
 
-  if(source == "datasus" | source == "ufrn"){
+  if(source == "datasus" | source == "datasus2024" | source == "ufrn"){
     res <- dplyr::bind_rows(mun_male_pop, mun_female_pop) %>%
       dplyr::filter(.data$age_group == "Total") %>%
       dtplyr::lazy_dt() %>%
