@@ -12,7 +12,19 @@
 #' }
 #'
 #' @references FREIRE, F.H.M.A; GONZAGA, M.R; QUEIROZ, B.L. Projeção populacional municipal com estimadores bayesianos, Brasil 2010 - 2030. In: Sawyer, D.O (coord.).  Seguridade Social Municipais. Projeto Brasil 3 Tempos. Secretaria  Especial de Assuntos Estratégicos da Presidência da República (SAE/SG/PR) , United Nations Development Programme, Brazil (UNDP) and International Policy  Centre for Inclusive Growth. Brasília (IPC-IG), 2019.
-ufrn_mun_female_pop <- function(){
-  path <- zendown::zen_file(deposit_id = zenodo_deposit, file_name = "ufrn_mun_female_pop.rds")
+ufrn_mun_female_pop <- function() {
+  path <- tryCatch(
+    {
+      zendown::zen_file(
+        deposit_id = zenodo_deposit,
+        file_name = "ufrn_mun_female_pop.rds"
+      )
+    },
+    error = function(cond) {
+      message(zendown_error_message)
+      message(conditionMessage(cond))
+    }
+  )
+
   readRDS(file = path)
 }
